<?php

namespace Litecms\Maintenance\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Litecms\Maintenance\Models\Contract;

class ContractPolicy
{

    use ContractAction;
    use ContractReport;
    use ContractWorkflow;

    /**
     * Determine if the given user can view the contract.
     *
     * @param Authenticatable $user
     * @param Contract $contract
     *
     * @return bool
     */
    public function view(Authenticatable $user, Contract $contract)
    {
        if ($authUser->canDo('maintenance.contract.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $contract->is_owner;
    }

    /**
     * Determine if the given user can create a contract.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('maintenance.contract.create');
    }

    /**
     * Determine if the given user can update the given contract.
     *
     * @param Authenticatable $user
     * @param Contract $contract
     *
     * @return bool
     */
    public function update(Authenticatable $user, Contract $contract)
    {
        if ($user->canDo('maintenance.contract.edit') && $user->isAdmin()) {
            return true;
        }

        return $contract->is_owner;
    }

    /**
     * Determine if the given user can delete the given contract.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Contract $contract)
    {
        return $contract->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
