<?php

namespace Litecms\Maintenance\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Litecms\Maintenance\Models\Proposal;

class ProposalPolicy
{

    use ProposalAction;
    use ProposalReport;
    use ProposalWorkflow;

    /**
     * Determine if the given user can view the proposal.
     *
     * @param Authenticatable $user
     * @param Proposal $proposal
     *
     * @return bool
     */
    public function view(Authenticatable $user, Proposal $proposal)
    {
        if ($authUser->canDo('maintenance.proposal.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $proposal->is_owner;
    }

    /**
     * Determine if the given user can create a proposal.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('maintenance.proposal.create');
    }

    /**
     * Determine if the given user can update the given proposal.
     *
     * @param Authenticatable $user
     * @param Proposal $proposal
     *
     * @return bool
     */
    public function update(Authenticatable $user, Proposal $proposal)
    {
        if ($user->canDo('maintenance.proposal.edit') && $user->isAdmin()) {
            return true;
        }

        return $proposal->is_owner;
    }

    /**
     * Determine if the given user can delete the given proposal.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Proposal $proposal)
    {
        return $proposal->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
