<?php

namespace Litecms\Maintenance\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Litecms\Maintenance\Models\Vendor;

class VendorPolicy
{

    use VendorAction;

    /**
     * Determine if the given user can view the vendor.
     *
     * @param Authenticatable $user
     * @param Vendor $vendor
     *
     * @return bool
     */
    public function view(Authenticatable $user, Vendor $vendor)
    {
        if ($authUser->canDo('maintenance.vendor.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $vendor->is_owner;
    }

    /**
     * Determine if the given user can create a vendor.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('maintenance.vendor.create');
    }

    /**
     * Determine if the given user can update the given vendor.
     *
     * @param Authenticatable $user
     * @param Vendor $vendor
     *
     * @return bool
     */
    public function update(Authenticatable $user, Vendor $vendor)
    {
        if ($user->canDo('maintenance.vendor.edit') && $user->isAdmin()) {
            return true;
        }

        return $vendor->is_owner;
    }

    /**
     * Determine if the given user can delete the given vendor.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Vendor $vendor)
    {
        return $vendor->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
