<?php

namespace Litecms\Maintenance\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Litecms\Maintenance\Models\Workorder;

class WorkorderPolicy
{

    use WorkorderAction;
    use WorkorderReport;
    use WorkorderWorkflow;

    /**
     * Determine if the given user can view the workorder.
     *
     * @param Authenticatable $user
     * @param Workorder $workorder
     *
     * @return bool
     */
    public function view(Authenticatable $user, Workorder $workorder)
    {
        if ($authUser->canDo('maintenance.workorder.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $workorder->is_owner;
    }

    /**
     * Determine if the given user can create a workorder.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('maintenance.workorder.create');
    }

    /**
     * Determine if the given user can update the given workorder.
     *
     * @param Authenticatable $user
     * @param Workorder $workorder
     *
     * @return bool
     */
    public function update(Authenticatable $user, Workorder $workorder)
    {
        if ($user->canDo('maintenance.workorder.edit') && $user->isAdmin()) {
            return true;
        }

        return $workorder->is_owner;
    }

    /**
     * Determine if the given user can delete the given workorder.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Workorder $workorder)
    {
        return $workorder->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
